/*
 * MIT License
 *
 * Copyright (c) 2023 Murray R. Van Luyn. green@bug-eyed.monster
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

/*!
 * \file C8_CO2_5K.h
 * \brief Shenzhen Shenchen Technology C8-CO2-5K 
 *           CO2 sensor library for Arduino
 * \details
 *      Source:         
 *      Documentation:  
 */

#ifndef C8_CO2_5K_H
#define C8_CO2_5K_H

#include <Arduino.h>

/*!
 * \brief Class C8_CO2_5K
 */
class C8_CO2_5K
{
public:
    C8_CO2_5K(Stream *serial);
    ~C8_CO2_5K();

    // Read CO2 value
    uint16_t getCO2(void);

    // Single point calibration manually at known ppm
    bool setCO2(uint16_t ppm_value);

private:
    Stream *_serial;    

    // CRC check on serial receive buffer
    uint16_t calcuCRC(uint8_t *dataarray, uint16_t datalen);

};

#endif // C8_CO2_5K_H