/*
 * MIT License
 *
 * Copyright (c) 2023 Murray R. Van Luyn. green@bug-eyed.monster
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

/*!
 * \file set_co2.ino
 * \brief Shenzhen Shenchen Technology C8-CO2-5K 
 *           CO2 sensor library for Arduino
 * \details
 *      Source:         
 *      Documentation:  
 */

#include <C8_CO2_5K.h>

// Pin defines
#if defined(ARDUINO_AVR_MEGA2560) || defined(ARDUINO_AVR_LEONARDO) || defined(ARDUINO_SAM_DUE)
    #define C8_CO2_5K_Serial        Serial1 // Use second hardware serial

#elif defined(ARDUINO_ARCH_AVR)
    #define C8_CO2_5K_TX_PIN        2
    #define C8_CO2_5K_RX_PIN        3

    #include <SoftwareSerial.h>          // Use software serial
    SoftwareSerial C8_CO2_5K_Serial(C8_CO2_5K_TX_PIN, C8_CO2_5K_RX_PIN);
#elif defined(ARDUINO_ARCH_ESP8266)
    #define C8_CO2_5K_TX_PIN        D5
    #define C8_CO2_5K_RX_PIN        D6

    #include <SoftwareSerial.h>          // Use software serial
    SoftwareSerial C8_CO2_5K_Serial(C8_CO2_5K_TX_PIN, C8_CO2_5K_RX_PIN);
#elif defined(ARDUINO_ARCH_ESP32)
    #define C8_CO2_5K_TX_PIN        18
    #define C8_CO2_5K_RX_PIN        19

    #include <SoftwareSerial.h>          // Use software serial
    SoftwareSerial C8_CO2_5K_Serial(C8_CO2_5K_TX_PIN, C8_CO2_5K_RX_PIN);
#else
    #error "May work, but not tested on this target"
#endif

// Create the C8_CO2_5K object
C8_CO2_5K c8_co2_5k(&C8_CO2_5K_Serial);

void setup()
{
  uint16_t co2 = 0;

  Serial.begin(115200);
  C8_CO2_5K_Serial.begin(9600);

  Serial.print("In 10-minutes+, enter CO2 concentration to set: ");
  while (Serial.available() == 0) continue;  // wait for user input
  co2 = Serial.parseInt();
  Serial.println(); 

  Serial.print("Read: ");
  Serial.print(co2);
  Serial.println();

  if (c8_co2_5k.setCO2(co2))
  {
    Serial.print("CO2 set to ");
    Serial.print(co2);
  }
  else
  {
    Serial.print("CO2 set failed");
  }
  Serial.println();
}

void loop()
{
  uint16_t co2 = c8_co2_5k.getCO2();

  Serial.print("CO2 concentration: ");
  Serial.println(co2);
  Serial.println();

  delay(5000);
}
